@@ -9,8 +9,9 @@ describe 'gnocchi::wsgi::apache' do
         :bind_port                   => 8041,
         :group                       => 'gnocchi',
         :path                        => '/',
+        :priority                    => 10,
         :servername                  => facts[:fqdn],
-        :ssl                         => true,
+        :ssl                         => false,
         :threads                     => 1,
         :user                        => 'gnocchi',
         :workers                     => facts[:os_workers],
@@ -19,28 +20,34 @@ describe 'gnocchi::wsgi::apache' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'app',
         :wsgi_script_source          => platform_params[:wsgi_script_source],
+        :headers                     => nil,
+        :request_headers             => nil,
         :custom_wsgi_process_options => {},
-        :access_log_file             => false,
-        :access_log_format           => false,
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
+        :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
       )}
     end
 
-    context 'when overriding paramters using different ports' do
+    context 'when overriding parameters' do
       let :params do
         {
           :servername                => 'dummy.host',
           :bind_host                 => '10.42.51.1',
           :port                      => 12345,
-          :ssl                       => false,
+          :ssl                       => true,
           :workers                   => 8,
           :wsgi_process_display_name => 'gnocchi',
           :threads                   => 2,
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/path',
           },
-          :access_log_file           => '/var/log/httpd/access_log',
-          :access_log_format         => 'some format',
-          :error_log_file            => '/var/log/httpd/error_log',
+          :headers                   => ['set X-XSS-Protection "1; mode=block"'],
+          :request_headers           => ['set Content-Type "application/json"'],
           :vhost_custom_fragment     => 'Timeout 99'
         }
       end
@@ -52,7 +59,7 @@ describe 'gnocchi::wsgi::apache' do
         :group                     => 'gnocchi',
         :path                      => '/',
         :servername                => 'dummy.host',
-        :ssl                       => false,
+        :ssl                       => true,
         :threads                   => 2,
         :user                      => 'gnocchi',
         :vhost_custom_fragment     => 'Timeout 99',
@@ -63,12 +70,75 @@ describe 'gnocchi::wsgi::apache' do
         :wsgi_script_dir           => platform_params[:wsgi_script_path],
         :wsgi_script_file          => 'app',
         :wsgi_script_source        => platform_params[:wsgi_script_source],
+        :headers                   => ['set X-XSS-Protection "1; mode=block"'],
+        :request_headers           => ['set Content-Type "application/json"'],
         :custom_wsgi_process_options => {
           'python_path' => '/my/python/path',
         },
-        :access_log_file           => '/var/log/httpd/access_log',
-        :access_log_format         => 'some format',
-        :error_log_file            => '/var/log/httpd/error_log'
+      )}
+    end
+
+    context 'with custom access logging' do
+      let :params do
+        {
+          :access_log_format => 'foo',
+          :access_log_syslog => 'syslog:local0',
+          :error_log_syslog  => 'syslog:local1',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('gnocchi_wsgi').with(
+        :access_log_format => params[:access_log_format],
+        :access_log_syslog => params[:access_log_syslog],
+        :error_log_syslog  => params[:error_log_syslog],
+      )}
+    end
+
+    context 'with access_log_file' do
+      let :params do
+        {
+          :access_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('gnocchi_wsgi').with(
+        :access_log_file => params[:access_log_file],
+      )}
+    end
+
+    context 'with access_log_pipe' do
+      let :params do
+        {
+          :access_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('gnocchi_wsgi').with(
+        :access_log_pipe => params[:access_log_pipe],
+      )}
+    end
+
+    context 'with error_log_file' do
+      let :params do
+        {
+          :error_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('gnocchi_wsgi').with(
+        :error_log_file => params[:error_log_file],
+      )}
+    end
+
+    context 'with error_log_pipe' do
+      let :params do
+        {
+          :error_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('gnocchi_wsgi').with(
+        :error_log_pipe => params[:error_log_pipe],
       )}
     end
   end
